import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = (data) => {
  const xValue = (d) => d.Students_enrolled;
  const yValue = (d) => d.Course;
  const margin = {
    top: 30,
    right: 50,
    left: 200,
    bottom: 70,
  };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.1);
  const yAxis = axisLeft(yScale);

  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`
    );

  yAxis(g.append('g'));

  g.append('g')
    .call(axisBottom(xScale))
    .attr('transform', `translate(0,${innerHeight})`);

  g.selectAll('rect')
    .data(data)
    .enter()
    .append('rect')
    .attr('y', (d) => yScale(yValue(d)))
    .attr('width', (d) => xScale(xValue(d)))
    .attr('height', yScale.bandwidth());
};
svg
  .append('text')
  .attr('class', 'x label')
  .attr('text-anchor', 'middle')
  .attr('x', width - 500)
  .attr('y', height - 15)
  .text('Number of Students enrolled');

svg
  .append('text')
  .attr('class', 'y label')
  .attr('text-anchor', 'middle')
  .attr('y', 30)

  .attr('dy', 'lem')

  .attr('x', 0 - height / 2)
  //.attr("y", 0-margin.left )
  .attr('transform', 'rotate(-90)')
  .text('Courses');

csv('data.csv').then((data) => {
  data.forEach((d) => {
    d.population = +d.population * 1000;
  });
  render(data);
});
